# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.tags_api import TagsApi  # noqa: E501
from asana.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Create a tag  # noqa: E501
        """
        pass

    def test_create_tag_for_workspace(self):
        """Test case for create_tag_for_workspace

        Create a tag in a workspace  # noqa: E501
        """
        pass

    def test_delete_tag(self):
        """Test case for delete_tag

        Delete a tag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Get a tag  # noqa: E501
        """
        pass

    def test_get_tags(self):
        """Test case for get_tags

        Get multiple tags  # noqa: E501
        """
        pass

    def test_get_tags_for_task(self):
        """Test case for get_tags_for_task

        Get a task's tags  # noqa: E501
        """
        pass

    def test_get_tags_for_workspace(self):
        """Test case for get_tags_for_workspace

        Get tags in a workspace  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Update a tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
