# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.stories_api import StoriesApi  # noqa: E501
from asana.rest import ApiException


class TestStoriesApi(unittest.TestCase):
    """StoriesApi unit test stubs"""

    def setUp(self):
        self.api = StoriesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_story_for_task(self):
        """Test case for create_story_for_task

        Create a story on a task  # noqa: E501
        """
        pass

    def test_delete_story(self):
        """Test case for delete_story

        Delete a story  # noqa: E501
        """
        pass

    def test_get_stories_for_task(self):
        """Test case for get_stories_for_task

        Get stories from a task  # noqa: E501
        """
        pass

    def test_get_story(self):
        """Test case for get_story

        Get a story  # noqa: E501
        """
        pass

    def test_update_story(self):
        """Test case for update_story

        Update a story  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
