# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.workspace_memberships_api import WorkspaceMembershipsApi  # noqa: E501
from asana.rest import ApiException


class TestWorkspaceMembershipsApi(unittest.TestCase):
    """WorkspaceMembershipsApi unit test stubs"""

    def setUp(self):
        self.api = WorkspaceMembershipsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_workspace_membership(self):
        """Test case for get_workspace_membership

        Get a workspace membership  # noqa: E501
        """
        pass

    def test_get_workspace_memberships_for_user(self):
        """Test case for get_workspace_memberships_for_user

        Get workspace memberships for a user  # noqa: E501
        """
        pass

    def test_get_workspace_memberships_for_workspace(self):
        """Test case for get_workspace_memberships_for_workspace

        Get the workspace memberships for a workspace  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
