# coding: utf-8

# flake8: noqa
"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from asana.models.add_custom_field_setting_request import AddCustomFieldSettingRequest
from asana.models.add_followers_request import AddFollowersRequest
from asana.models.add_members_request import AddMembersRequest
from asana.models.all_of_project_response_owner import AllOfProjectResponseOwner
from asana.models.all_of_project_template_base_owner import AllOfProjectTemplateBaseOwner
from asana.models.all_of_project_template_response_owner import AllOfProjectTemplateResponseOwner
from asana.models.all_of_story_response_new_date_value import AllOfStoryResponseNewDateValue
from asana.models.all_of_story_response_old_date_value import AllOfStoryResponseOldDateValue
from asana.models.all_of_user_task_list_base_owner import AllOfUserTaskListBaseOwner
from asana.models.all_of_user_task_list_base_workspace import AllOfUserTaskListBaseWorkspace
from asana.models.all_of_user_task_list_compact_owner import AllOfUserTaskListCompactOwner
from asana.models.all_of_user_task_list_compact_workspace import AllOfUserTaskListCompactWorkspace
from asana.models.all_of_user_task_list_request_owner import AllOfUserTaskListRequestOwner
from asana.models.all_of_user_task_list_request_workspace import AllOfUserTaskListRequestWorkspace
from asana.models.all_of_user_task_list_response_owner import AllOfUserTaskListResponseOwner
from asana.models.all_of_user_task_list_response_workspace import AllOfUserTaskListResponseWorkspace
from asana.models.all_of_workspace_membership_response_user_task_list_owner import AllOfWorkspaceMembershipResponseUserTaskListOwner
from asana.models.all_of_workspace_membership_response_user_task_list_workspace import AllOfWorkspaceMembershipResponseUserTaskListWorkspace
from asana.models.asana_named_resource import AsanaNamedResource
from asana.models.asana_named_resource_array import AsanaNamedResourceArray
from asana.models.asana_resource import AsanaResource
from asana.models.attachment_base import AttachmentBase
from asana.models.attachment_compact import AttachmentCompact
from asana.models.attachment_request import AttachmentRequest
from asana.models.attachment_response import AttachmentResponse
from asana.models.attachment_response_array import AttachmentResponseArray
from asana.models.attachment_response_data import AttachmentResponseData
from asana.models.attachment_response_parent import AttachmentResponseParent
from asana.models.audit_log_event import AuditLogEvent
from asana.models.audit_log_event_actor import AuditLogEventActor
from asana.models.audit_log_event_array import AuditLogEventArray
from asana.models.audit_log_event_context import AuditLogEventContext
from asana.models.audit_log_event_details import AuditLogEventDetails
from asana.models.audit_log_event_resource import AuditLogEventResource
from asana.models.batch_body import BatchBody
from asana.models.batch_request import BatchRequest
from asana.models.batch_request_action import BatchRequestAction
from asana.models.batch_request_actions import BatchRequestActions
from asana.models.batch_request_options import BatchRequestOptions
from asana.models.batch_response import BatchResponse
from asana.models.batch_response_array import BatchResponseArray
from asana.models.create_membership_request import CreateMembershipRequest
from asana.models.create_time_tracking_entry_request import CreateTimeTrackingEntryRequest
from asana.models.custom_field_base import CustomFieldBase
from asana.models.custom_field_base_date_value import CustomFieldBaseDateValue
from asana.models.custom_field_base_enum_options import CustomFieldBaseEnumOptions
from asana.models.custom_field_base_enum_value import CustomFieldBaseEnumValue
from asana.models.custom_field_compact import CustomFieldCompact
from asana.models.custom_field_gid_enum_options_body import CustomFieldGidEnumOptionsBody
from asana.models.custom_field_request import CustomFieldRequest
from asana.models.custom_field_response import CustomFieldResponse
from asana.models.custom_field_response_array import CustomFieldResponseArray
from asana.models.custom_field_response_created_by import CustomFieldResponseCreatedBy
from asana.models.custom_field_response_data import CustomFieldResponseData
from asana.models.custom_field_response_people_value import CustomFieldResponsePeopleValue
from asana.models.custom_field_setting_base import CustomFieldSettingBase
from asana.models.custom_field_setting_compact import CustomFieldSettingCompact
from asana.models.custom_field_setting_response import CustomFieldSettingResponse
from asana.models.custom_field_setting_response_array import CustomFieldSettingResponseArray
from asana.models.custom_field_setting_response_custom_field import CustomFieldSettingResponseCustomField
from asana.models.custom_field_setting_response_data import CustomFieldSettingResponseData
from asana.models.custom_field_setting_response_parent import CustomFieldSettingResponseParent
from asana.models.custom_field_setting_response_project import CustomFieldSettingResponseProject
from asana.models.custom_fields_body import CustomFieldsBody
from asana.models.custom_fields_custom_field_gid_body import CustomFieldsCustomFieldGidBody
from asana.models.date_variable_compact import DateVariableCompact
from asana.models.date_variable_request import DateVariableRequest
from asana.models.empty_response import EmptyResponse
from asana.models.empty_response_data import EmptyResponseData
from asana.models.enum_option import EnumOption
from asana.models.enum_option_base import EnumOptionBase
from asana.models.enum_option_data import EnumOptionData
from asana.models.enum_option_insert_request import EnumOptionInsertRequest
from asana.models.enum_option_request import EnumOptionRequest
from asana.models.enum_options_enum_option_gid_body import EnumOptionsEnumOptionGidBody
from asana.models.enum_options_insert_body import EnumOptionsInsertBody
from asana.models.error import Error
from asana.models.error_response import ErrorResponse
from asana.models.error_response_errors import ErrorResponseErrors
from asana.models.event_response import EventResponse
from asana.models.event_response_array import EventResponseArray
from asana.models.event_response_change import EventResponseChange
from asana.models.event_response_parent import EventResponseParent
from asana.models.event_response_resource import EventResponseResource
from asana.models.event_response_user import EventResponseUser
from asana.models.goal_add_subgoal_request import GoalAddSubgoalRequest
from asana.models.goal_add_supporting_relationship_request import GoalAddSupportingRelationshipRequest
from asana.models.goal_add_supporting_work_request import GoalAddSupportingWorkRequest
from asana.models.goal_base import GoalBase
from asana.models.goal_compact import GoalCompact
from asana.models.goal_gid_add_followers_body import GoalGidAddFollowersBody
from asana.models.goal_gid_add_supporting_relationship_body import GoalGidAddSupportingRelationshipBody
from asana.models.goal_gid_remove_followers_body import GoalGidRemoveFollowersBody
from asana.models.goal_gid_remove_supporting_relationship_body import GoalGidRemoveSupportingRelationshipBody
from asana.models.goal_gid_set_metric_body import GoalGidSetMetricBody
from asana.models.goal_gid_set_metric_current_value_body import GoalGidSetMetricCurrentValueBody
from asana.models.goal_membership_base import GoalMembershipBase
from asana.models.goal_membership_compact import GoalMembershipCompact
from asana.models.goal_membership_response import GoalMembershipResponse
from asana.models.goal_membership_response_user import GoalMembershipResponseUser
from asana.models.goal_membership_response_workspace import GoalMembershipResponseWorkspace
from asana.models.goal_metric_base import GoalMetricBase
from asana.models.goal_metric_current_value_request import GoalMetricCurrentValueRequest
from asana.models.goal_metric_request import GoalMetricRequest
from asana.models.goal_relationship_base import GoalRelationshipBase
from asana.models.goal_relationship_base_supported_goal import GoalRelationshipBaseSupportedGoal
from asana.models.goal_relationship_base_supporting_resource import GoalRelationshipBaseSupportingResource
from asana.models.goal_relationship_compact import GoalRelationshipCompact
from asana.models.goal_relationship_request import GoalRelationshipRequest
from asana.models.goal_relationship_response import GoalRelationshipResponse
from asana.models.goal_relationship_response_array import GoalRelationshipResponseArray
from asana.models.goal_relationship_response_data import GoalRelationshipResponseData
from asana.models.goal_relationships_goal_relationship_gid_body import GoalRelationshipsGoalRelationshipGidBody
from asana.models.goal_remove_subgoal_request import GoalRemoveSubgoalRequest
from asana.models.goal_remove_supporting_relationship_request import GoalRemoveSupportingRelationshipRequest
from asana.models.goal_request import GoalRequest
from asana.models.goal_request_base import GoalRequestBase
from asana.models.goal_response import GoalResponse
from asana.models.goal_response_array import GoalResponseArray
from asana.models.goal_response_current_status_update import GoalResponseCurrentStatusUpdate
from asana.models.goal_response_data import GoalResponseData
from asana.models.goal_response_likes import GoalResponseLikes
from asana.models.goal_response_metric import GoalResponseMetric
from asana.models.goal_response_team import GoalResponseTeam
from asana.models.goal_response_time_period import GoalResponseTimePeriod
from asana.models.goal_response_workspace import GoalResponseWorkspace
from asana.models.goal_update_request import GoalUpdateRequest
from asana.models.goals_body import GoalsBody
from asana.models.goals_goal_gid_body import GoalsGoalGidBody
from asana.models.inline_response412 import InlineResponse412
from asana.models.inline_response412_errors import InlineResponse412Errors
from asana.models.job_base import JobBase
from asana.models.job_base_new_project import JobBaseNewProject
from asana.models.job_base_new_project_template import JobBaseNewProjectTemplate
from asana.models.job_base_new_task import JobBaseNewTask
from asana.models.job_compact import JobCompact
from asana.models.job_response import JobResponse
from asana.models.job_response_data import JobResponseData
from asana.models.like import Like
from asana.models.member_compact import MemberCompact
from asana.models.membership_compact import MembershipCompact
from asana.models.membership_compact_goal import MembershipCompactGoal
from asana.models.membership_compact_member import MembershipCompactMember
from asana.models.membership_compact_parent import MembershipCompactParent
from asana.models.membership_request import MembershipRequest
from asana.models.membership_response import MembershipResponse
from asana.models.membership_response_array import MembershipResponseArray
from asana.models.membership_response_data import MembershipResponseData
from asana.models.memberships_body import MembershipsBody
from asana.models.modify_dependencies_request import ModifyDependenciesRequest
from asana.models.modify_dependents_request import ModifyDependentsRequest
from asana.models.next_page import NextPage
from asana.models.organization_export_base import OrganizationExportBase
from asana.models.organization_export_compact import OrganizationExportCompact
from asana.models.organization_export_request import OrganizationExportRequest
from asana.models.organization_export_response import OrganizationExportResponse
from asana.models.organization_export_response_data import OrganizationExportResponseData
from asana.models.organization_exports_body import OrganizationExportsBody
from asana.models.portfolio_add_item_request import PortfolioAddItemRequest
from asana.models.portfolio_base import PortfolioBase
from asana.models.portfolio_compact import PortfolioCompact
from asana.models.portfolio_gid_add_custom_field_setting_body import PortfolioGidAddCustomFieldSettingBody
from asana.models.portfolio_gid_add_item_body import PortfolioGidAddItemBody
from asana.models.portfolio_gid_add_members_body import PortfolioGidAddMembersBody
from asana.models.portfolio_gid_remove_custom_field_setting_body import PortfolioGidRemoveCustomFieldSettingBody
from asana.models.portfolio_gid_remove_item_body import PortfolioGidRemoveItemBody
from asana.models.portfolio_gid_remove_members_body import PortfolioGidRemoveMembersBody
from asana.models.portfolio_membership_base import PortfolioMembershipBase
from asana.models.portfolio_membership_base_portfolio import PortfolioMembershipBasePortfolio
from asana.models.portfolio_membership_compact import PortfolioMembershipCompact
from asana.models.portfolio_membership_response import PortfolioMembershipResponse
from asana.models.portfolio_membership_response_array import PortfolioMembershipResponseArray
from asana.models.portfolio_membership_response_data import PortfolioMembershipResponseData
from asana.models.portfolio_remove_item_request import PortfolioRemoveItemRequest
from asana.models.portfolio_request import PortfolioRequest
from asana.models.portfolio_response import PortfolioResponse
from asana.models.portfolio_response_array import PortfolioResponseArray
from asana.models.portfolio_response_current_status_update import PortfolioResponseCurrentStatusUpdate
from asana.models.portfolio_response_custom_field_settings import PortfolioResponseCustomFieldSettings
from asana.models.portfolio_response_custom_fields import PortfolioResponseCustomFields
from asana.models.portfolio_response_data import PortfolioResponseData
from asana.models.portfolio_response_workspace import PortfolioResponseWorkspace
from asana.models.portfolios_body import PortfoliosBody
from asana.models.portfolios_portfolio_gid_body import PortfoliosPortfolioGidBody
from asana.models.preview import Preview
from asana.models.project_base import ProjectBase
from asana.models.project_base_current_status import ProjectBaseCurrentStatus
from asana.models.project_base_current_status_update import ProjectBaseCurrentStatusUpdate
from asana.models.project_brief_base import ProjectBriefBase
from asana.models.project_brief_compact import ProjectBriefCompact
from asana.models.project_brief_request import ProjectBriefRequest
from asana.models.project_brief_response import ProjectBriefResponse
from asana.models.project_brief_response_data import ProjectBriefResponseData
from asana.models.project_brief_response_project import ProjectBriefResponseProject
from asana.models.project_briefs_project_brief_gid_body import ProjectBriefsProjectBriefGidBody
from asana.models.project_compact import ProjectCompact
from asana.models.project_duplicate_request import ProjectDuplicateRequest
from asana.models.project_duplicate_request_schedule_dates import ProjectDuplicateRequestScheduleDates
from asana.models.project_gid_add_custom_field_setting_body import ProjectGidAddCustomFieldSettingBody
from asana.models.project_gid_add_followers_body import ProjectGidAddFollowersBody
from asana.models.project_gid_add_members_body import ProjectGidAddMembersBody
from asana.models.project_gid_duplicate_body import ProjectGidDuplicateBody
from asana.models.project_gid_project_briefs_body import ProjectGidProjectBriefsBody
from asana.models.project_gid_project_statuses_body import ProjectGidProjectStatusesBody
from asana.models.project_gid_remove_custom_field_setting_body import ProjectGidRemoveCustomFieldSettingBody
from asana.models.project_gid_remove_followers_body import ProjectGidRemoveFollowersBody
from asana.models.project_gid_remove_members_body import ProjectGidRemoveMembersBody
from asana.models.project_gid_save_as_template_body import ProjectGidSaveAsTemplateBody
from asana.models.project_gid_sections_body import ProjectGidSectionsBody
from asana.models.project_membership_base import ProjectMembershipBase
from asana.models.project_membership_compact import ProjectMembershipCompact
from asana.models.project_membership_compact_array import ProjectMembershipCompactArray
from asana.models.project_membership_compact_response import ProjectMembershipCompactResponse
from asana.models.project_membership_normal_response import ProjectMembershipNormalResponse
from asana.models.project_membership_normal_response_data import ProjectMembershipNormalResponseData
from asana.models.project_request import ProjectRequest
from asana.models.project_response import ProjectResponse
from asana.models.project_response_array import ProjectResponseArray
from asana.models.project_response_completed_by import ProjectResponseCompletedBy
from asana.models.project_response_created_from_template import ProjectResponseCreatedFromTemplate
from asana.models.project_response_data import ProjectResponseData
from asana.models.project_response_project_brief import ProjectResponseProjectBrief
from asana.models.project_response_team import ProjectResponseTeam
from asana.models.project_response_workspace import ProjectResponseWorkspace
from asana.models.project_save_as_template_request import ProjectSaveAsTemplateRequest
from asana.models.project_section_insert_request import ProjectSectionInsertRequest
from asana.models.project_status_base import ProjectStatusBase
from asana.models.project_status_compact import ProjectStatusCompact
from asana.models.project_status_request import ProjectStatusRequest
from asana.models.project_status_response import ProjectStatusResponse
from asana.models.project_status_response_array import ProjectStatusResponseArray
from asana.models.project_status_response_data import ProjectStatusResponseData
from asana.models.project_template_base import ProjectTemplateBase
from asana.models.project_template_base_requested_dates import ProjectTemplateBaseRequestedDates
from asana.models.project_template_base_requested_roles import ProjectTemplateBaseRequestedRoles
from asana.models.project_template_base_team import ProjectTemplateBaseTeam
from asana.models.project_template_compact import ProjectTemplateCompact
from asana.models.project_template_gid_instantiate_project_body import ProjectTemplateGidInstantiateProjectBody
from asana.models.project_template_instantiate_project_request import ProjectTemplateInstantiateProjectRequest
from asana.models.project_template_instantiate_project_request_requested_dates import ProjectTemplateInstantiateProjectRequestRequestedDates
from asana.models.project_template_instantiate_project_request_requested_roles import ProjectTemplateInstantiateProjectRequestRequestedRoles
from asana.models.project_template_response import ProjectTemplateResponse
from asana.models.project_template_response_array import ProjectTemplateResponseArray
from asana.models.project_template_response_data import ProjectTemplateResponseData
from asana.models.project_update_request import ProjectUpdateRequest
from asana.models.projects_body import ProjectsBody
from asana.models.projects_project_gid_body import ProjectsProjectGidBody
from asana.models.remove_custom_field_setting_request import RemoveCustomFieldSettingRequest
from asana.models.remove_followers_request import RemoveFollowersRequest
from asana.models.remove_members_request import RemoveMembersRequest
from asana.models.requested_role_request import RequestedRoleRequest
from asana.models.rule_trigger_gid_run_body import RuleTriggerGidRunBody
from asana.models.rule_trigger_request import RuleTriggerRequest
from asana.models.rule_trigger_response import RuleTriggerResponse
from asana.models.rule_trigger_response_data import RuleTriggerResponseData
from asana.models.section_base import SectionBase
from asana.models.section_compact import SectionCompact
from asana.models.section_gid_add_task_body import SectionGidAddTaskBody
from asana.models.section_request import SectionRequest
from asana.models.section_response import SectionResponse
from asana.models.section_response_array import SectionResponseArray
from asana.models.section_response_data import SectionResponseData
from asana.models.section_task_insert_request import SectionTaskInsertRequest
from asana.models.sections_insert_body import SectionsInsertBody
from asana.models.sections_section_gid_body import SectionsSectionGidBody
from asana.models.status_update_base import StatusUpdateBase
from asana.models.status_update_compact import StatusUpdateCompact
from asana.models.status_update_request import StatusUpdateRequest
from asana.models.status_update_response import StatusUpdateResponse
from asana.models.status_update_response_array import StatusUpdateResponseArray
from asana.models.status_update_response_data import StatusUpdateResponseData
from asana.models.status_update_response_parent import StatusUpdateResponseParent
from asana.models.status_updates_body import StatusUpdatesBody
from asana.models.stories_story_gid_body import StoriesStoryGidBody
from asana.models.story_base import StoryBase
from asana.models.story_compact import StoryCompact
from asana.models.story_request import StoryRequest
from asana.models.story_response import StoryResponse
from asana.models.story_response_array import StoryResponseArray
from asana.models.story_response_assignee import StoryResponseAssignee
from asana.models.story_response_custom_field import StoryResponseCustomField
from asana.models.story_response_data import StoryResponseData
from asana.models.story_response_dates import StoryResponseDates
from asana.models.story_response_old_dates import StoryResponseOldDates
from asana.models.story_response_old_enum_value import StoryResponseOldEnumValue
from asana.models.story_response_old_section import StoryResponseOldSection
from asana.models.story_response_previews import StoryResponsePreviews
from asana.models.story_response_project import StoryResponseProject
from asana.models.story_response_story import StoryResponseStory
from asana.models.story_response_tag import StoryResponseTag
from asana.models.story_response_target import StoryResponseTarget
from asana.models.story_response_task import StoryResponseTask
from asana.models.tag_base import TagBase
from asana.models.tag_compact import TagCompact
from asana.models.tag_request import TagRequest
from asana.models.tag_response import TagResponse
from asana.models.tag_response_array import TagResponseArray
from asana.models.tag_response_data import TagResponseData
from asana.models.tags_body import TagsBody
from asana.models.task_add_followers_request import TaskAddFollowersRequest
from asana.models.task_add_project_request import TaskAddProjectRequest
from asana.models.task_add_tag_request import TaskAddTagRequest
from asana.models.task_base import TaskBase
from asana.models.task_base_completed_by import TaskBaseCompletedBy
from asana.models.task_base_dependencies import TaskBaseDependencies
from asana.models.task_base_external import TaskBaseExternal
from asana.models.task_base_memberships import TaskBaseMemberships
from asana.models.task_base_section import TaskBaseSection
from asana.models.task_compact import TaskCompact
from asana.models.task_count_response import TaskCountResponse
from asana.models.task_count_response_data import TaskCountResponseData
from asana.models.task_duplicate_request import TaskDuplicateRequest
from asana.models.task_gid_add_dependencies_body import TaskGidAddDependenciesBody
from asana.models.task_gid_add_dependents_body import TaskGidAddDependentsBody
from asana.models.task_gid_add_followers_body import TaskGidAddFollowersBody
from asana.models.task_gid_add_project_body import TaskGidAddProjectBody
from asana.models.task_gid_add_tag_body import TaskGidAddTagBody
from asana.models.task_gid_duplicate_body import TaskGidDuplicateBody
from asana.models.task_gid_remove_dependencies_body import TaskGidRemoveDependenciesBody
from asana.models.task_gid_remove_dependents_body import TaskGidRemoveDependentsBody
from asana.models.task_gid_remove_followers_body import TaskGidRemoveFollowersBody
from asana.models.task_gid_remove_project_body import TaskGidRemoveProjectBody
from asana.models.task_gid_remove_tag_body import TaskGidRemoveTagBody
from asana.models.task_gid_set_parent_body import TaskGidSetParentBody
from asana.models.task_gid_stories_body import TaskGidStoriesBody
from asana.models.task_gid_subtasks_body import TaskGidSubtasksBody
from asana.models.task_gid_time_tracking_entries_body import TaskGidTimeTrackingEntriesBody
from asana.models.task_remove_followers_request import TaskRemoveFollowersRequest
from asana.models.task_remove_project_request import TaskRemoveProjectRequest
from asana.models.task_remove_tag_request import TaskRemoveTagRequest
from asana.models.task_request import TaskRequest
from asana.models.task_response import TaskResponse
from asana.models.task_response_array import TaskResponseArray
from asana.models.task_response_assignee_section import TaskResponseAssigneeSection
from asana.models.task_response_custom_fields import TaskResponseCustomFields
from asana.models.task_response_data import TaskResponseData
from asana.models.task_response_parent import TaskResponseParent
from asana.models.task_response_tags import TaskResponseTags
from asana.models.task_response_workspace import TaskResponseWorkspace
from asana.models.task_set_parent_request import TaskSetParentRequest
from asana.models.tasks_body import TasksBody
from asana.models.tasks_task_gid_body import TasksTaskGidBody
from asana.models.team_add_user_request import TeamAddUserRequest
from asana.models.team_base import TeamBase
from asana.models.team_compact import TeamCompact
from asana.models.team_gid_add_user_body import TeamGidAddUserBody
from asana.models.team_gid_projects_body import TeamGidProjectsBody
from asana.models.team_gid_remove_user_body import TeamGidRemoveUserBody
from asana.models.team_membership_base import TeamMembershipBase
from asana.models.team_membership_compact import TeamMembershipCompact
from asana.models.team_membership_response import TeamMembershipResponse
from asana.models.team_membership_response_array import TeamMembershipResponseArray
from asana.models.team_membership_response_data import TeamMembershipResponseData
from asana.models.team_remove_user_request import TeamRemoveUserRequest
from asana.models.team_request import TeamRequest
from asana.models.team_response import TeamResponse
from asana.models.team_response_array import TeamResponseArray
from asana.models.team_response_data import TeamResponseData
from asana.models.team_response_organization import TeamResponseOrganization
from asana.models.teams_body import TeamsBody
from asana.models.teams_team_gid_body import TeamsTeamGidBody
from asana.models.template_role import TemplateRole
from asana.models.time_period_base import TimePeriodBase
from asana.models.time_period_compact import TimePeriodCompact
from asana.models.time_period_response import TimePeriodResponse
from asana.models.time_period_response_array import TimePeriodResponseArray
from asana.models.time_period_response_data import TimePeriodResponseData
from asana.models.time_tracking_entries_time_tracking_entry_gid_body import TimeTrackingEntriesTimeTrackingEntryGidBody
from asana.models.time_tracking_entry_base import TimeTrackingEntryBase
from asana.models.time_tracking_entry_base_data import TimeTrackingEntryBaseData
from asana.models.time_tracking_entry_compact import TimeTrackingEntryCompact
from asana.models.time_tracking_entry_compact_array import TimeTrackingEntryCompactArray
from asana.models.update_time_tracking_entry_request import UpdateTimeTrackingEntryRequest
from asana.models.user_base import UserBase
from asana.models.user_base_response import UserBaseResponse
from asana.models.user_base_response_data import UserBaseResponseData
from asana.models.user_base_response_photo import UserBaseResponsePhoto
from asana.models.user_compact import UserCompact
from asana.models.user_request import UserRequest
from asana.models.user_response import UserResponse
from asana.models.user_response_array import UserResponseArray
from asana.models.user_response_data import UserResponseData
from asana.models.user_task_list_base import UserTaskListBase
from asana.models.user_task_list_compact import UserTaskListCompact
from asana.models.user_task_list_request import UserTaskListRequest
from asana.models.user_task_list_response import UserTaskListResponse
from asana.models.user_task_list_response_data import UserTaskListResponseData
from asana.models.webhook_compact import WebhookCompact
from asana.models.webhook_compact_resource import WebhookCompactResource
from asana.models.webhook_filter import WebhookFilter
from asana.models.webhook_request import WebhookRequest
from asana.models.webhook_request_filters import WebhookRequestFilters
from asana.models.webhook_response import WebhookResponse
from asana.models.webhook_response_array import WebhookResponseArray
from asana.models.webhook_response_data import WebhookResponseData
from asana.models.webhook_update_request import WebhookUpdateRequest
from asana.models.webhooks_body import WebhooksBody
from asana.models.webhooks_webhook_gid_body import WebhooksWebhookGidBody
from asana.models.workspace_add_user_request import WorkspaceAddUserRequest
from asana.models.workspace_base import WorkspaceBase
from asana.models.workspace_compact import WorkspaceCompact
from asana.models.workspace_gid_add_user_body import WorkspaceGidAddUserBody
from asana.models.workspace_gid_projects_body import WorkspaceGidProjectsBody
from asana.models.workspace_gid_remove_user_body import WorkspaceGidRemoveUserBody
from asana.models.workspace_gid_tags_body import WorkspaceGidTagsBody
from asana.models.workspace_membership_base import WorkspaceMembershipBase
from asana.models.workspace_membership_compact import WorkspaceMembershipCompact
from asana.models.workspace_membership_request import WorkspaceMembershipRequest
from asana.models.workspace_membership_response import WorkspaceMembershipResponse
from asana.models.workspace_membership_response_array import WorkspaceMembershipResponseArray
from asana.models.workspace_membership_response_data import WorkspaceMembershipResponseData
from asana.models.workspace_membership_response_user_task_list import WorkspaceMembershipResponseUserTaskList
from asana.models.workspace_membership_response_vacation_dates import WorkspaceMembershipResponseVacationDates
from asana.models.workspace_remove_user_request import WorkspaceRemoveUserRequest
from asana.models.workspace_request import WorkspaceRequest
from asana.models.workspace_response import WorkspaceResponse
from asana.models.workspace_response_array import WorkspaceResponseArray
from asana.models.workspace_response_data import WorkspaceResponseData
from asana.models.workspaces_workspace_gid_body import WorkspacesWorkspaceGidBody
