# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.tasks_api import TasksApi  # noqa: E501
from asana.rest import ApiException


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_dependencies_for_task(self):
        """Test case for add_dependencies_for_task

        Set dependencies for a task  # noqa: E501
        """
        pass

    def test_add_dependents_for_task(self):
        """Test case for add_dependents_for_task

        Set dependents for a task  # noqa: E501
        """
        pass

    def test_add_followers_for_task(self):
        """Test case for add_followers_for_task

        Add followers to a task  # noqa: E501
        """
        pass

    def test_add_project_for_task(self):
        """Test case for add_project_for_task

        Add a project to a task  # noqa: E501
        """
        pass

    def test_add_tag_for_task(self):
        """Test case for add_tag_for_task

        Add a tag to a task  # noqa: E501
        """
        pass

    def test_create_subtask_for_task(self):
        """Test case for create_subtask_for_task

        Create a subtask  # noqa: E501
        """
        pass

    def test_create_task(self):
        """Test case for create_task

        Create a task  # noqa: E501
        """
        pass

    def test_delete_task(self):
        """Test case for delete_task

        Delete a task  # noqa: E501
        """
        pass

    def test_duplicate_task(self):
        """Test case for duplicate_task

        Duplicate a task  # noqa: E501
        """
        pass

    def test_get_dependencies_for_task(self):
        """Test case for get_dependencies_for_task

        Get dependencies from a task  # noqa: E501
        """
        pass

    def test_get_dependents_for_task(self):
        """Test case for get_dependents_for_task

        Get dependents from a task  # noqa: E501
        """
        pass

    def test_get_subtasks_for_task(self):
        """Test case for get_subtasks_for_task

        Get subtasks from a task  # noqa: E501
        """
        pass

    def test_get_task(self):
        """Test case for get_task

        Get a task  # noqa: E501
        """
        pass

    def test_get_tasks(self):
        """Test case for get_tasks

        Get multiple tasks  # noqa: E501
        """
        pass

    def test_get_tasks_for_project(self):
        """Test case for get_tasks_for_project

        Get tasks from a project  # noqa: E501
        """
        pass

    def test_get_tasks_for_section(self):
        """Test case for get_tasks_for_section

        Get tasks from a section  # noqa: E501
        """
        pass

    def test_get_tasks_for_tag(self):
        """Test case for get_tasks_for_tag

        Get tasks from a tag  # noqa: E501
        """
        pass

    def test_get_tasks_for_user_task_list(self):
        """Test case for get_tasks_for_user_task_list

        Get tasks from a user task list  # noqa: E501
        """
        pass

    def test_remove_dependencies_for_task(self):
        """Test case for remove_dependencies_for_task

        Unlink dependencies from a task  # noqa: E501
        """
        pass

    def test_remove_dependents_for_task(self):
        """Test case for remove_dependents_for_task

        Unlink dependents from a task  # noqa: E501
        """
        pass

    def test_remove_follower_for_task(self):
        """Test case for remove_follower_for_task

        Remove followers from a task  # noqa: E501
        """
        pass

    def test_remove_project_for_task(self):
        """Test case for remove_project_for_task

        Remove a project from a task  # noqa: E501
        """
        pass

    def test_remove_tag_for_task(self):
        """Test case for remove_tag_for_task

        Remove a tag from a task  # noqa: E501
        """
        pass

    def test_search_tasks_for_workspace(self):
        """Test case for search_tasks_for_workspace

        Search tasks in a workspace  # noqa: E501
        """
        pass

    def test_set_parent_for_task(self):
        """Test case for set_parent_for_task

        Set the parent of a task  # noqa: E501
        """
        pass

    def test_update_task(self):
        """Test case for update_task

        Update a task  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
