# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.api.users_api import UsersApi  # noqa: E501
from asana.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_favorites_for_user(self):
        """Test case for get_favorites_for_user

        Get a user's favorites  # noqa: E501
        """
        pass

    def test_get_user(self):
        """Test case for get_user

        Get a user  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get multiple users  # noqa: E501
        """
        pass

    def test_get_users_for_team(self):
        """Test case for get_users_for_team

        Get users in a team  # noqa: E501
        """
        pass

    def test_get_users_for_workspace(self):
        """Test case for get_users_for_workspace

        Get users in a workspace or organization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
