# coding: utf-8

"""
    Asana

    This is the interface for interacting with the [Asana Platform](https://developers.asana.com). Our API reference is generated from our [OpenAPI spec] (https://raw.githubusercontent.com/Asana/openapi/master/defs/asana_oas.yaml).  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import asana
from asana.models.custom_field_setting_response_custom_field import CustomFieldSettingResponseCustomField  # noqa: E501
from asana.rest import ApiException


class TestCustomFieldSettingResponseCustomField(unittest.TestCase):
    """CustomFieldSettingResponseCustomField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCustomFieldSettingResponseCustomField(self):
        """Test CustomFieldSettingResponseCustomField"""
        # FIXME: construct object with mandatory attributes with example values
        # model = asana.models.custom_field_setting_response_custom_field.CustomFieldSettingResponseCustomField()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
